Transition class

Constructors

Transition({TransitionType type = TransitionType.fade, int duration = 1})

Properties

duration int
final
hashCode int
The hash code for this object.
no setterinherited
offset int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TransitionType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setOffset(int duration, [int previousOffset = 0]) int
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited