ImageLayer class

Inheritance

Constructors

ImageLayer.asset(String path, {double? opacity, num? x, num? y, double? scale})
ImageLayer.file(String path, {double? opacity, num? x, num? y, double? scale})

Properties

hashCode int
The hash code for this object.
no setterinherited
opacity double?
getter/setter pair
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double?
getter/setter pair
type FileType
final
x num?
getter/setter pair
y num?
getter/setter pair

Methods

brightness(double value) Future<void>
contrast(double value) Future<void>
crop({required int width, required int height}) Future<void>
export(String input, int? fps, String output, int height, int width) Future<bool>
gamma(double value) Future<void>
hflip() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotate(int degree) Future<void>
saturation(double value) Future<void>
save(String output) Future<bool>
toString() String
A string representation of this object.
inherited
vflip() Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited