TextCmd class
text cmd
Constructors
Properties
- bgcolor → Color?
-
background color
final
- end → int?
-
end duration in sec
final
- fontcolor → Color
-
font color
final
- fontFile → FontFile?
-
font file
final
- fontsize → int
-
font size
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rotate → int?
-
rotate in degree
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int?
-
start duration in sec
final
- text → String
-
string text
final
- x → double?
-
x position
final
- y → double?
-
y position
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toFutureString(
) → Future< String> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited