TextLayer class
Constructors
Properties
- bgColor ↔ Color
-
getter/setter pair
- color ↔ Color
-
getter/setter pair
- end ↔ int?
-
getter/setter pair
- fontFamily ↔ String?
-
getter/setter pair
- fontFile ↔ FontFile?
-
getter/setter pair
- fontSize ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- rotate ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start ↔ int?
-
getter/setter pair
- text → String
-
final
- x ↔ int?
-
getter/setter pair
- y ↔ int?
-
getter/setter pair
Methods
-
glow(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited