VideoLayer class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int?
-
getter/setter pair
- isMute ↔ bool
-
getter/setter pair
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → FileType
-
final
- width ↔ int?
-
getter/setter pair
- x ↔ int?
-
getter/setter pair
- y ↔ int?
-
getter/setter pair
Methods
-
export(
String input, int? fps, String output) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited